# Logout on Timeout

## Introduction

This module allows site administrators to set a timeout that automatically logs users out after a specified period of inactivity with a pop-up that alerts users of their session timeout that includes a session extension or the ability for the user to directly log out.

## Features

* Full configuration of alert messaging, including pop-up alert and tab title alert.
* Supports multiple tabs that synchronize the session status to ensure simultaneous logouts.
* Uses Web Workers to ensure correct timing synchronization across all open tabs, even when the tabs are no longer active.
* Includes a query parameter on logout so custom messages can be crafted within the site's theme.
* Supports the simpleSAMLphp Authentication module to ensure redirection to the configured log out target (bypassing the hard coded log out destination set by simpleSAMLphp Authentication).
* Supports User Event Dispatcher to work with simpleSAMLphp Authentication. This ensures that events are captured when logging out of simpleSAMLphp Authentication sessions from this module.

## Background

This module uses a highly modified version of the [Idle Hands](https://github.com/totallyquiche/idle-hands) JavaScript to manage user timing, along with Drupal JQuery to manage script configuration. The end user must have JavaScript enabled in order for this module to function. It is recommended that this module only be used on sites that require JavaScript.

This module was developed with a particular set of requirements, including synchronization across all open tabs (active or no), a flashing tab bar, a logout alert that included the ability of end users to log out directly and integration with simpleSAMLphp Authentication, but lacks a number of other features such as role based timeout, displayed timer and developer hooks. So this module may not be for all installations, but might be perfect for yours. For a more generalized module with greater flexibility, [Automated Logout](https://www.drupal.org/project/autologout) is recommended.

## Post-Installation

* Permissions configuration: Home >> Administration >> People (/admin/people/permissions)
* Module configuration: Home >> Administration >> Configuration >> People (/admin/config/people/logout_timeout)
* This module is installed with features disabled. Ensure you enable the module from the configuration form before use.
* This module allows for logging out users who have logged into Drupal using the simpleSAMLphp Authentication module. Select the "Use simpleSAMLphp Authentication" checkbox if you have users who log into Drupal using the simpleSAMLphp Authentication module. Enabeling this feature without simpleSAMLphp Authentication enabled will do nothing.
* This module can send events to the Hook Event Dispatcher's sub-module User Event Dispatcher when using simpleSAMLphp Authentication. Select the "Use Hook Event Dispatcher" checkbox to fire a logout event. Enabeling this feature without both the User Event Dispatcher and the simpleSAMLphp Authentication modules enabled will do nothing.

## Additional Requirements

This module requires the Drupal core User module to be enabled. It is recommended only on sites that require JavaScript to be enabled.

## Similar Projects

* [Automated Logout](https://www.drupal.org/project/autologout)
* [Inactive Autologout](https://www.drupal.org/project/inactive_autologout)
* [Simple Autologout](https://www.drupal.org/project/simpleautologout)
